@@ -14,7 +14,6 @@
 
 
 from oslo_log import log as logging
-import six
 
 from sahara import context
 from sahara.i18n import _
@@ -27,7 +26,6 @@ import sahara.plugins.mapr.util.validation_utils as vu
 import sahara.plugins.provisioning as p
 from sahara.utils import files
 
-
 LOG = logging.getLogger(__name__)
 
 CLDB = np.NodeProcess(
@@ -50,13 +48,14 @@ NFS = np.NodeProcess(
 )
 
 
-@six.add_metaclass(s.Single)
 class MapRFS(s.Service):
     _CREATE_DISK_LIST = 'plugins/mapr/resources/create_disk_list_file.sh'
     _DISK_SETUP_CMD = '/opt/mapr/server/disksetup -F /tmp/disk.list'
     _DISK_SETUP_TIMEOUT = 600
 
     ENABLE_MAPR_DB_NAME = 'Enable MapR-DB'
+    HEAP_SIZE_PERCENT_NAME = 'MapR-FS heap size percent'
+
     ENABLE_MAPR_DB_CONFIG = p.Config(
         name=ENABLE_MAPR_DB_NAME,
         applicable_target='general',
@@ -67,12 +66,24 @@ class MapRFS(s.Service):
         description=_('Specifies that MapR-DB is in use.')
     )
 
+    HEAP_SIZE_PERCENT = p.Config(
+        name=HEAP_SIZE_PERCENT_NAME,
+        applicable_target='MapRFS',
+        scope='cluster',
+        config_type="int",
+        priority=1,
+        default_value=8,
+        description=_(
+            'Specifies heap size for MapR-FS in percents of maximum value.')
+    )
+
     def __init__(self):
         super(MapRFS, self).__init__()
         self._ui_name = 'MapRFS'
         self._node_processes = [CLDB, FILE_SERVER, NFS]
         self._ui_info = [
-            ('Container Location Database (CLDB)', CLDB, 'http://%s:7221'),
+            ('Container Location Database (CLDB)', CLDB,
+             {s.SERVICE_UI: 'http://%s:7221'}),
         ]
         self._validation_rules = [
             vu.at_least(1, CLDB),
@@ -116,7 +127,7 @@ class MapRFS(s.Service):
                 timeout=self._DISK_SETUP_TIMEOUT)
 
     def get_configs(self):
-        return [MapRFS.ENABLE_MAPR_DB_CONFIG]
+        return [MapRFS.ENABLE_MAPR_DB_CONFIG, MapRFS.HEAP_SIZE_PERCENT]
 
     def get_config_files(self, cluster_context, configs, instance=None):
         default_path = 'plugins/mapr/services/maprfs/resources/cldb.conf'
@@ -127,8 +138,16 @@ class MapRFS(s.Service):
         cldb_conf.parse(files.get_file_text(default_path))
         cldb_conf.add_properties(self._get_cldb_conf_props(cluster_context))
 
-        return [cldb_conf]
+        warden_conf = bcf.PropertiesFile("warden.conf")
+        warden_conf.remote_path = "/opt/mapr/conf/"
+        if instance:
+            warden_conf.fetch(instance)
+        warden_conf.add_properties(
+            {'service.command.mfs.heapsize.percent': configs[
+                self.HEAP_SIZE_PERCENT_NAME]})
 
-    def _get_cldb_conf_props(self, context):
-        zookeepers = context.get_zookeeper_nodes_ip_with_port()
+        return [cldb_conf, warden_conf]
+
+    def _get_cldb_conf_props(self, cluster_context):
+        zookeepers = cluster_context.get_zookeeper_nodes_ip_with_port()
         return {'cldb.zookeeper.servers': zookeepers}
