@@ -19,7 +19,6 @@ from oslo_config import cfg
 
 from sahara.service import sessions
 import sahara.utils.openstack.base as base
-from sahara.utils.openstack import images
 from sahara.utils.openstack import keystone
 
 
@@ -46,8 +45,8 @@ CONF.register_opts(opts, group=nova_group)
 def client():
     session = sessions.cache().get_session(sessions.SESSION_TYPE_NOVA)
     nova = nova_client.Client('2', session=session, auth=keystone.auth(),
-                              endpoint_type=CONF.nova.endpoint_type)
-    nova.images = images.SaharaImageManager(nova)
+                              endpoint_type=CONF.nova.endpoint_type,
+                              region_name=CONF.os_region_name)
     return nova
 
 
